

Overview
========

.. only:: html

    :Release: |version|
    :Date: |today|

    Download `PDF <Matplotlib.pdf>`_


.. toctree::
   :maxdepth: 2

   users/index.rst
   faq/index.rst
   api/index.rst
   resources/index.rst
   thirdpartypackages/index.rst
   devel/index.rst
   glossary/index.rst

.. only:: html

  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`
